@@ -1,9 +1,9 @@
 BUILD_BIT = '64bit'
 BUILD_CPU = 'ARMv8 (64-bit) Family 8 Model D4C Revision   0, Qualcomm Technologies Inc'
-BUILD_DATE = '2024-10-20'
+BUILD_DATE = '2024-10-24'
 BUILD_MACHINE = 'ARM64'
 BUILD_OS = 'Microsoft Windows 11 Pro'
-BUILD_TIME = '06:43'
+BUILD_TIME = '14:41'
 BUILD_TYPE = ''
 COMPILER_VERSION = 'clang version 18.1.8'
 CYTHON_VERSION = '3.0.11'
@@ -95,7 +95,7 @@ lib_mingww64clangaarch64clanganalyzer = '18.1.8-1'
 lib_mingww64clangaarch64clanglibs = '18.1.8-1'
 lib_mingww64clangaarch64clangtoolsextra = '18.1.8-1'
 lib_mingww64clangaarch64compilerrt = '18.1.8-1'
-lib_mingww64clangaarch64crtgit = '12.0.0.r351.gcdf6b16b8-1'
+lib_mingww64clangaarch64crtgit = '12.0.0.r360.gac299df46-1'
 lib_mingww64clangaarch64cython = '3.0.11-1'
 lib_mingww64clangaarch64eglheaders = '1.5.r255.9ab6036-1'
 lib_mingww64clangaarch64expat = '2.6.3-1'
@@ -112,7 +112,7 @@ lib_mingww64clangaarch64graphite2 = '1.3.14-3'
 lib_mingww64clangaarch64gtk3 = '3.24.43-1'
 lib_mingww64clangaarch64gtkupdateiconcache = '3.24.43-1'
 lib_mingww64clangaarch64harfbuzz = '10.0.1-1'
-lib_mingww64clangaarch64headersgit = '12.0.0.r351.gcdf6b16b8-1'
+lib_mingww64clangaarch64headersgit = '12.0.0.r360.gac299df46-1'
 lib_mingww64clangaarch64hicoloricontheme = '0.18-1'
 lib_mingww64clangaarch64jbigkit = '2.1-5'
 lib_mingww64clangaarch64jsonglib = '1.10.0-1'
@@ -126,10 +126,11 @@ lib_mingww64clangaarch64libffi = '3.4.6-1'
 lib_mingww64clangaarch64libiconv = '1.17-4'
 lib_mingww64clangaarch64libimagequant = '4.3.3-1'
 lib_mingww64clangaarch64libjpegturbo = '3.0.4-2'
-lib_mingww64clangaarch64libmanglegit = '12.0.0.r351.gcdf6b16b8-1'
+lib_mingww64clangaarch64libmanglegit = '12.0.0.r360.gac299df46-1'
 lib_mingww64clangaarch64libpng = '1.6.44-1'
 lib_mingww64clangaarch64libraqm = '0.10.2-1'
 lib_mingww64clangaarch64librsvg = '2.59.1-2'
+lib_mingww64clangaarch64libspng = '0.7.4-1'
 lib_mingww64clangaarch64libsystre = '1.0.1-6'
 lib_mingww64clangaarch64libthai = '0.1.29-3'
 lib_mingww64clangaarch64libtiff = '4.7.0-1'
@@ -137,7 +138,7 @@ lib_mingww64clangaarch64libtre = '0.9.0-1'
 lib_mingww64clangaarch64libunwind = '18.1.8-2'
 lib_mingww64clangaarch64libvpx = '1.14.1-1'
 lib_mingww64clangaarch64libwebp = '1.4.0-1'
-lib_mingww64clangaarch64libwinpthreadgit = '12.0.0.r351.gcdf6b16b8-1'
+lib_mingww64clangaarch64libwinpthreadgit = '12.0.0.r360.gac299df46-1'
 lib_mingww64clangaarch64libx264 = '0.164.r3161.a354f11-3'
 lib_mingww64clangaarch64libxml2 = '2.12.9-1'
 lib_mingww64clangaarch64libyuv = '1887.r2537.a6a2ec65-1'
@@ -161,15 +162,13 @@ lib_mingww64clangaarch64pkgconf = '1~2.3.0-1'
 lib_mingww64clangaarch64python = '3.11.10-1'
 lib_mingww64clangaarch64pythonbuild = '1.2.2-1'
 lib_mingww64clangaarch64pythoncairo = '1.27.0-1'
-lib_mingww64clangaarch64pythoncomtypes = '1.4.7-1'
+lib_mingww64clangaarch64pythoncomtypes = '1.4.8-1'
 lib_mingww64clangaarch64pythongobject = '3.50.0-1'
 lib_mingww64clangaarch64pythoninstaller = '0.7.0-3'
-lib_mingww64clangaarch64pythonlz4 = '4.3.3-2'
 lib_mingww64clangaarch64pythonpackaging = '24.1-2'
-lib_mingww64clangaarch64pythonpillow = '10.4.0-1'
+lib_mingww64clangaarch64pythonpillow = '11.0.0-1'
 lib_mingww64clangaarch64pythonpyopengl = '3.1.7-3'
 lib_mingww64clangaarch64pythonpyprojecthooks = '1.1.0-1'
-lib_mingww64clangaarch64pythonrencode = '1.0.6-6'
 lib_mingww64clangaarch64pythonsetproctitle = '1.3.3-1'
 lib_mingww64clangaarch64pythonsetuptools = '75.1.0-2'
 lib_mingww64clangaarch64pythonsix = '1.16.0-4'
@@ -179,11 +178,11 @@ lib_mingww64clangaarch64sqlite3 = '3.46.1-1'
 lib_mingww64clangaarch64tcl = '8.6.13-1'
 lib_mingww64clangaarch64termcap = '1.3.1-7'
 lib_mingww64clangaarch64tk = '8.6.13-1'
-lib_mingww64clangaarch64toolsgit = '12.0.0.r351.gcdf6b16b8-1'
+lib_mingww64clangaarch64toolsgit = '12.0.0.r360.gac299df46-1'
 lib_mingww64clangaarch64tzdata = '2024b-1'
 lib_mingww64clangaarch64wineditline = '2.208-1'
-lib_mingww64clangaarch64winpthreadsgit = '12.0.0.r351.gcdf6b16b8-1'
-lib_mingww64clangaarch64winstorecompatgit = '12.0.0.r351.gcdf6b16b8-1'
+lib_mingww64clangaarch64winpthreadsgit = '12.0.0.r360.gac299df46-1'
+lib_mingww64clangaarch64winstorecompatgit = '12.0.0.r360.gac299df46-1'
 lib_mingww64clangaarch64xxhash = '0.8.2-2'
 lib_mingww64clangaarch64xz = '5.6.3-1'
 lib_mingww64clangaarch64zlib = '1.3.1-1'
